package com.logicbig.example;

import com.logicbig.uicommon.YamlToTreeNodeCreator;
import javax.swing.*;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.TreeNode;
import javax.swing.tree.TreePath;
import java.awt.*;

public class TreeExampleMain {
    public static void main(String[] args) {
        TreeNode treeNode =
                YamlToTreeNodeCreator.createTreeNodeFromYaml("/countries.yml");
        JTree tree = new JTree(treeNode);
        tree.setCellRenderer(new CountriesTreeRenderer());
        tree.addTreeSelectionListener(createTreeSelectionListener());
        JFrame frame = createFrame();
        frame.add(new JScrollPane(tree));
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }

    private static TreeSelectionListener createTreeSelectionListener() {
        return treeSelectionEvent -> {
            TreePath path = treeSelectionEvent.getPath();
            System.out.println("Path: " + path);
            String nodeType = null;
            Object userObject = null;
            Object[] paths = path.getPath();
            switch (paths.length) {
                case 1:
                    nodeType = "World";
                    userObject = paths[0];
                    break;
                case 2:
                    nodeType = "Continent";
                    userObject = paths[1];
                    break;
                case 3:
                    nodeType = "Country";
                    userObject = paths[2];
                    break;
            }
            System.out.printf("nodeType: %s, userObject: %s%n", nodeType, userObject);
            System.out.println("-------");
        };
    }

    private static JFrame createFrame() {
        JFrame frame = new JFrame("JTree from YAML example");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(new Dimension(500, 400));
        return frame;
    }
}